@@ -11,6 +11,7 @@ from urllib import parse
 import requests
 from click import ClickException
 from openpyxl import Workbook
+from openpyxl.comments import Comment
 from openpyxl.styles import Alignment, Font, PatternFill
 from openpyxl.styles.colors import Color, WHITE
 from openpyxl.utils import quote_sheetname
@@ -22,6 +23,7 @@ from connect.cli.core.http import (
     format_http_status,
     handle_http_error,
 )
+from connect.cli.core.utils import validate_output_options
 from connect.cli.plugins.product.constants import PARAM_TYPES
 from connect.cli.plugins.product.utils import (
     get_col_headers_by_ws_type,
@@ -92,6 +94,19 @@ def _setup_cover_sheet(ws, product, location, client, media_path):
     ws['B13'].alignment = Alignment(
         wrap_text=True,
     )
+    ws['A14'].value = 'Primary Translation Locale'
+    ws['A14'].comment = Comment(
+        "This attribute will not be updated on product sync",
+        "ccli product dump",
+    )
+    primary_translation = (
+        client.ns('localization').translations
+        .filter(context__instance_id=product['id'], primary=True).first()
+    )
+    ws['B14'].value = (
+        f'{ primary_translation["locale"]["id"] } '
+        f'({ primary_translation["locale"]["name"] })'
+    )
 
     categories = client.categories.all()
     unassignable_cat = ['Cloud Services', 'All Categories']
@@ -99,18 +114,29 @@ def _setup_cover_sheet(ws, product, location, client, media_path):
         cat['name'] for cat in categories if cat['name'] not in unassignable_cat
     ]
     ws['AA1'].value = 'Categories'
-    cat_row_idx = 2
-    for cat in categories_list:
-        ws[f'AA{cat_row_idx}'].value = cat
-        cat_row_idx += 1
+    for idx, cat in enumerate(categories_list, 2):
+        ws[f'AA{idx}'].value = cat
     categories_validation = DataValidation(
         type='list',
-        formula1=f'{quote_sheetname("General Information")}!$AA$2:$AA${len(categories_list)}',
+        formula1=f'{quote_sheetname("General Information")}!$AA$2:$AA${idx}',
         allow_blank=False,
     )
     ws.add_data_validation(categories_validation)
     categories_validation.add('B8')
 
+    locales = client.ns('localization').locales.all()
+    locales_list = [f"{locale['id']} ({locale['name']})" for locale in locales]
+    ws['AB1'].value = 'Locales'
+    for idx, loc in enumerate(locales_list, 2):
+        ws[f'AB{idx}'].value = loc
+    locales_validation = DataValidation(
+        type='list',
+        formula1=f'{quote_sheetname("General Information")}!$AB$2:$AB${idx}',
+        allow_blank=False,
+    )
+    ws.add_data_validation(locales_validation)
+    locales_validation.add('B14')
+
 
 def _dump_image(image_location, image_name, media_path):
     image = requests.get(image_location)
@@ -848,29 +874,8 @@ def _dump_items(ws, client, product_id, silent):
 
 
 def dump_product(api_url, api_key, product_id, output_file, silent, verbose=False, output_path=None):  # noqa: CCR001
-    if not output_path:
-        output_path = os.path.join(os.getcwd(), product_id)
-    else:
-        if not os.path.exists(output_path):
-            raise ClickException(
-                "Output Path does not exist",
-            )
-        output_path = os.path.join(output_path, product_id)
-
-    media_path = os.path.join(output_path, 'media')
-
-    if not output_file:
-        output_file = os.path.join(output_path, f'{product_id}.xlsx')
-    else:
-        output_file = os.path.join(output_path, output_file)
-
-    if not os.path.exists(output_path):
-        os.mkdir(output_path)
-    elif not os.path.isdir(output_path):
-        raise ClickException(
-            "Exists a file with product name but a directory is expected, please rename it",
-        )
-
+    output_file = validate_output_options(output_path, output_file, default_dir_name=product_id)
+    media_path = os.path.join(os.path.dirname(output_file), 'media')
     if not os.path.exists(media_path):
         os.mkdir(media_path)
     try:
